California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 85 - WAITING PERIOD AND PARENTAL NOTIFICATION BEFORE TERMINATION OF MINOR'S PREGNANCY. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1276142 | CAMPAIGN FOR TEEN SAFETY - NO ON 85 - A PROJECT OF PLANNED PARENTHOOD AFFILIATES OF CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1289848 | COMMITTEE FOR CALIFORNIA'S FUTURE, YES ON PROPS 1A, 1B, 1C, 1D, 1E, 84 AND NO ON 85 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1291431 | VOTE NO ON PROP. 85, SPONSORED BY FEMINIST MAJORITY FOUNDATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288785 | NO ON 85, A PROJECT OF AMERICAN CIVIL LIBERTIES UNION OF NORTHERN CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1257969 | YES ON 85, MAJOR FUNDING PROVIDED BY JIM HOLMAN, DON SEBASTIANI, AND OTHERS TO REFORM PARENTS' RIGHT TO KNOW AND CHILD PROTECTION LAWS IN CALIFORNIA. (AKA "LIFE ON THE BALLOT - PARENTS RIGHT TO KNOW") | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288982 | CITIZENS FOR RESPONSIBLE ELECTIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1291816 | CATHOLICS FOR 85, SUPPORTED BY CATHOLICS FOR THE COMMON GOOD | SUPPORT